"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const require_1 = require("./require");
const log_1 = require("./log");
class PluginsLoader {
    constructor(config, account) {
        this.config = config;
        this.account = account;
        this.tryLoading = () => {
            if (document.querySelector('[data-react-class="Mastodon"]') === null) {
                log_1.default.info('Root element of react app was not found. App seems not to be loaded yet.');
                return false;
            }
            for (const key in this.preloads) {
                const f = this.preloads[key];
                try {
                    f(this.config, this.account);
                }
                catch (e) {
                    log_1.default.error(`Error while loading preload plugin '${key}':`, e);
                }
            }
            log_1.default.info('Preload plugins were loaded:', this.preloads);
            return true;
        };
        this.loaded = false;
        this.preloads = {};
        if (config.chromium_sandbox) {
            log_1.default.info('Chromium sandbox is enabled. Preload plugin is disabled.');
            return;
        }
        const dir_base = path.join(config.__DATA_DIR, 'node_modules');
        for (const plugin of config.preload || []) {
            const plugin_path = path.join(dir_base, `mstdn-preload-${plugin}`);
            try {
                this.preloads[plugin_path] = require_1.default(plugin_path);
            }
            catch (e) {
                log_1.default.error(`Failed to load plugin ${plugin_path}:`, e);
            }
        }
    }
    loadAfterAppPrepared() {
        if (Object.keys(this.preloads).length === 0) {
            log_1.default.info('No preload plugin found. Skip loading');
            this.loaded = true;
            return;
        }
        return new Promise(resolve => {
            window.requestIdleCallback(() => {
                log_1.default.debug('Start loading preload plugins', this.config, this.account);
                if (this.tryLoading()) {
                    return resolve();
                }
                this.observeAppPrepared(this.tryLoading).then(resolve);
            });
        });
    }
    observeAppPrepared(callback) {
        return Promise.resolve(callback());
    }
}
exports.default = PluginsLoader;
//# sourceMappingURL=plugins.js.map